@@ -929,11 +929,15 @@ def policy_maintenance_set(context,  # pylint: disable=too-many-branches, too-ma
         result = context.obj['opsgenie'].list_alert_policy(context.obj.get('teamid'))
         for filt_ in filter_:
             filtered_results = [x for x in result['data'] if (filt_).lower() in (x['name']).lower()]
-            if len(filtered_results) == 1:
+            if len(filtered_results) == 0:
+                raise click.UsageError(
+                    f"\nNo alert filters found for {filt_}."
+                )
+            elif len(filtered_results) == 1:
                 id_.append(filtered_results[0]['id'])
                 filters_enabled.append(filtered_results[0]['name'])
             else:
-                print(f"\nMultiple maintenance filters found for {filt_}.")
+                print(f"\nMultiple alert filters found for {filt_}.")
                 filtered_format_table = PrettyTable(['id', 'name', 'type', 'enabled'])
                 for result in filtered_results:
                     filtered_format_table.add_row([result['id'], result['name'], result['type'], result['enabled']])
@@ -1525,8 +1529,12 @@ def schedules_get(context, id_, team_name):
 
 @schedules.command(name='timeline')
 @click.option('--team-name', 'team_name', required=True)
+@click.option('--expand', type=click.Choice(['base', 'forwarding', 'override'], case_sensitive=False))
+@click.option('--interval')
+@click.option('--intervalunit')
+@click.option('--history', is_flag=True)
 @click.pass_context
-def schedules_timeline(context, team_name):
+def schedules_timeline(context, team_name, history, expand, interval=1, intervalunit="weeks"):  # pylint: disable=too-many-locals, too-many-arguments
     """
     Function to list the schedules for all teams
 
@@ -1535,20 +1543,34 @@ def schedules_timeline(context, team_name):
 
     """
     team_schedule_name = find_team_schedule_name_by_name(team_name)  # pylint: disable=no-value-for-parameter
-    result = context.obj['opsgenie'].list_schedule_timeline_by_team_name(team_schedule_name)
+    result = context.obj['opsgenie'].list_schedule_timeline_by_team_name(team_schedule_name, expand, interval, intervalunit)
+
+    rotation = 'finalTimeline'
+    if expand:
+        rotation = f'{expand}Timeline'
+
+    if not result['data'][f'{rotation}']['rotations']:
+        print('No schedules were found, exiting..')
+        return
+
     format_table = PrettyTable(['user', 'startdate', 'enddate'])
-    for item in result['data']['finalTimeline']['rotations'][0]['periods']:
-        time_zone = pytz.timezone("UTC")
+    print(f'\n On-call schedules - {rotation.lower()}')
 
-        start_dt_truncated = (item['startDate'].replace('Z', '')).split(".")[0]
-        start_utc_dt = time_zone.localize((datetime.fromisoformat(start_dt_truncated)))
-        start_ams_dt = (start_utc_dt.astimezone(pytz.timezone("Europe/Amsterdam"))).strftime('%Y-%m-%d %H:%M:%S')
+    for item in result['data'][f'{rotation}']['rotations'][0]['periods']:
+        if not history and datetime.now() >= datetime.strptime((item['startDate'].replace('Z', '')).split(".")[0], "%Y-%m-%dT%H:%M:%S"):
+            continue
+        else:
+            time_zone = pytz.timezone("UTC")
 
-        end_dt_truncated = (item['endDate'].replace('Z', '')).split(".")[0]
-        end_utc_dt = time_zone.localize((datetime.fromisoformat(end_dt_truncated)))
-        end_ams_dt = (end_utc_dt.astimezone(pytz.timezone("Europe/Amsterdam"))).strftime('%Y-%m-%d %H:%M:%S')
+            start_dt_truncated = (item['startDate'].replace('Z', '')).split(".")[0]
+            start_utc_dt = time_zone.localize((datetime.fromisoformat(start_dt_truncated)))
+            start_ams_dt = (start_utc_dt.astimezone(pytz.timezone("Europe/Amsterdam"))).strftime('%Y-%m-%d %H:%M:%S')
 
-        format_table.add_row([item['recipient']['name'], start_ams_dt, end_ams_dt])
+            end_dt_truncated = (item['endDate'].replace('Z', '')).split(".")[0]
+            end_utc_dt = time_zone.localize((datetime.fromisoformat(end_dt_truncated)))
+            end_ams_dt = (end_utc_dt.astimezone(pytz.timezone("Europe/Amsterdam"))).strftime('%Y-%m-%d %H:%M:%S')
+
+            format_table.add_row([item['recipient']['name'], start_ams_dt, end_ams_dt])
     print(format_table)
 
 
